#include <LiquidCrystal.h>
#include "DHT.h"

#define DHTPIN 10
#define DHTTYPE DHT22

// initialise the LCD and specify how it is connected to the MCU.
const int rs = 6, en = 5, d4 = 0, d5 = 1, d6 = 2, d7 = 3;
LiquidCrystal lcd(rs, en, d4, d5, d6, d7);

// Initialise the sensor and specify connection.
DHT dht(DHTPIN, DHTTYPE);

void setup() {
  lcd.begin(16, 2);  // WE are using a 1602 LCD.
  dht.begin();

  // Print a message to the LCD.
  lcd.clear();
  lcd.print("Reading...");
}

char buffer[18];

void loop() {

  // Wait a few seconds between measurements.
  delay(2000);

  // Read relative humidity
  float h = dht.readHumidity();
  // Read temperature as Celsius (the default)
  float t = dht.readTemperature();

  // Check if any reads failed and exit early (to try again).
  if (isnan(h) || isnan(t)) {
    lcd.setCursor(0, 1);
    lcd.print("NaN");
    return;
  }

  // Compute heat index in Celsius (isFahreheit = false)
  float hic = dht.computeHeatIndex(t, h, false);
  // Display the data
  lcd.setCursor(0, 0);
  dtostrf(t,5,1,buffer);
  lcd.print(buffer);
  lcd.print("C ");
  dtostrf(h,5,1,buffer);
  lcd.print(buffer);
  lcd.print("% RH");
  lcd.setCursor(0, 1);
  lcd.print("Feels Like");
  dtostrf(hic,5,1,buffer);
  lcd.print(buffer);
  lcd.print("C");
}
